@@ -1,11 +1,9 @@
-import sys
 import time
 
 import requests
-from progress.bar import Bar
-from progress.spinner import Spinner
+from progress.bar import ChargingBar
+from progress.spinner import PixelSpinner
 
-from .common import getResponse
 from .web.urls import TASK_STATUS_URL
 
 FAILURE = "FAILURE"
@@ -17,6 +15,8 @@ TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
 
 import threading
 
+bar_suffix = '%(percent)d%% || %(eta)d seconds remaining || %(elapsed)d seconds elapsed'
+
 
 class Task:
 
@@ -27,6 +27,7 @@ class Task:
         self.progress = 0
         self.task_state = PENDING
         self.callback = callback
+        self.cache = None
         self._metrics = {}
         if self.callback:
             t = threading.Thread(target=self.callback_thread)
@@ -37,9 +38,9 @@ class Task:
 
     def wait(self, show_progress=False):
         if show_progress:
-            bar = Bar('Training', suffix='%(percent)d%%', stream=sys.stdout)
+            bar = ChargingBar('Training', suffix=bar_suffix)
         else:
-            spinner = Spinner('Task in Progress')
+            spinner = PixelSpinner('Task in Progress ')
         while not self.finished():
             time.sleep(0.1)
             if show_progress:
@@ -48,10 +49,11 @@ class Task:
                 spinner.next()
         if self.task_state == FAILURE:
             self.update(include_result=True)
-            raise Exception("ERROR for task {}:{}".format(self.task_id, self.task_result))
+            raise Exception("ERROR for task {}: {}".format(self.task_id, self.task_result))
         if self.task_state == STOPPED:
             print("Task has been stopped.")
         if show_progress:
+            bar.goto(100)
             bar.finish()
         else:
             spinner.finish()
@@ -66,6 +68,7 @@ class Task:
         return self.task_result
 
     def update(self, include_result=False):
+        from .common import getResponse
         params = {"include_result": include_result}
         response = requests.get(TASK_STATUS_URL + self.task_id, params=params)
         response = getResponse(response)
