@@ -1,3 +1,5 @@
+import os
+
 import bson
 import requests
 
@@ -43,10 +45,10 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             print("Model not found on server.")
             print("Saving model locally...")
         file_path = save_model(model, library)
+        print(file_path)
         with open(file_path, "rb") as file:
-            size = 0
-            for piece in read_in_chunks(file):
-                size += len(piece)
+            file.seek(0, os.SEEK_END)
+            size = file.tell()
             if getVerbosity() >= MID_VERBOSITY:
                 print("Model saved locally.")
             print("Model file size is {}. Uploading model now...".format(convert_size(size)))
