@@ -22,6 +22,8 @@ def exportApi(model, path):
     params = {"token": getToken()}
     if isinstance(model, Model):
         params["model_name"] = model.name
+    elif isinstance(model, str):
+        params["model_name"] = model
     elif model != "":
         params["modelId"] = model
     response = requests.get(EXPORT_URL, params=params, stream=True)
