@@ -9,10 +9,10 @@ from .web.urls import PREDICT_URL
 
 def predict(model, data, asynchronous=False, callback=None, **kwargs):
     checkModel(model)
-    if isinstance(model, Task) and model.cache is not None and "model" in model.cache:
-        cached_model = model.cache["model"]
-        if not isinstance(data, (str, Dataset, dict)):
-            validate_model(cached_model, data)
+    # if isinstance(model, Task) and model.cache is not None and "model" in model.cache:
+    #     cached_model = model.cache["model"]
+    #     if not isinstance(data, (str, Dataset, dict)):
+    #         validate_model(cached_model, data)
     inference_data = checkData(data)
     task_id = model.task_id if isinstance(model, Task) else ""
     resp = predictApi(model, inference_data, task_id, **kwargs)
